@@ -23,7 +23,7 @@
 #include "generator.h"
 #include "constants.h"
 
-#include <QtCore/QString>
+#include <QString>
 
 namespace Syndication
 {
